@@ -9,23 +9,30 @@ from moderator import utils
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
         make_option('-c', '--count',
-            dest='count',
-            type="int",
-            default=0,
-            help='Number of comments to classify.'),
-        )
+                    dest='count',
+                    type="int",
+                    default=0,
+                    help='Number of comments to classify.'),
+    )
     help = 'Classifies comments as either spam or '\
            'ham using Bayesian inference and user reports.'
 
     def handle(self, *args, **options):
-        # Collect all comments that hasn't already been classified or are classified as unsure.
-        # Order randomly so we don't rehash previously unsure classifieds when count limiting.
-        comments = Comment.objects.filter(Q(classifiedcomment__isnull=True) | Q(classifiedcomment__cls='unsure')).order_by('?')
+        """
+        Collect all comments that hasn't already been
+        classified or are classified as unsure.
+        Order randomly so we don't rehash previously unsure classifieds
+        when count limiting.
+        """
+        comments = Comment.objects.filter(
+            Q(classifiedcomment__isnull=True) |
+            Q(classifiedcomment__cls='unsure')).order_by('?')
         if options['count']:
             comments = comments[:options['count']]
         comment_count = comments.count()
 
-        self.stdout.write('Classifying %s comments, please wait...' % comment_count)
+        self.stdout.write('Classifying %s comments, please wait...' %
+                          comment_count)
         self.stdout.flush()
 
         for comment in comments:
